pub struct RollingPacketCaptureDetachRequest {
pub name: String,
}Fields
name: StringTrait Implementations
Sourceimpl Clone for RollingPacketCaptureDetachRequest
impl Clone for RollingPacketCaptureDetachRequest
Sourcefn clone(&self) -> RollingPacketCaptureDetachRequest
fn clone(&self) -> RollingPacketCaptureDetachRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D: ResourceDialect> Decode<RollingPacketCaptureDetachRequest, D> for RollingPacketCaptureDetachRequest
impl<D: ResourceDialect> Decode<RollingPacketCaptureDetachRequest, D> for RollingPacketCaptureDetachRequest
Sourceimpl<D: ResourceDialect> Encode<RollingPacketCaptureDetachRequest, D> for &RollingPacketCaptureDetachRequest
impl<D: ResourceDialect> Encode<RollingPacketCaptureDetachRequest, D> for &RollingPacketCaptureDetachRequest
Sourceimpl<D: ResourceDialect, T0: Encode<BoundedString<64>, D>> Encode<RollingPacketCaptureDetachRequest, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<BoundedString<64>, D>> Encode<RollingPacketCaptureDetachRequest, D> for (T0,)
Sourceimpl Ord for RollingPacketCaptureDetachRequest
impl Ord for RollingPacketCaptureDetachRequest
Sourcefn cmp(&self, other: &RollingPacketCaptureDetachRequest) -> Ordering
fn cmp(&self, other: &RollingPacketCaptureDetachRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for RollingPacketCaptureDetachRequest
impl PartialEq for RollingPacketCaptureDetachRequest
Sourcefn eq(&self, other: &RollingPacketCaptureDetachRequest) -> bool
fn eq(&self, other: &RollingPacketCaptureDetachRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for RollingPacketCaptureDetachRequest
impl PartialOrd for RollingPacketCaptureDetachRequest
Sourceimpl TypeMarker for RollingPacketCaptureDetachRequest
impl TypeMarker for RollingPacketCaptureDetachRequest
Sourcetype Owned = RollingPacketCaptureDetachRequest
type Owned = RollingPacketCaptureDetachRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for RollingPacketCaptureDetachRequest
impl ValueTypeMarker for RollingPacketCaptureDetachRequest
Sourcetype Borrowed<'a> = &'a RollingPacketCaptureDetachRequest
type Borrowed<'a> = &'a RollingPacketCaptureDetachRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Eq for RollingPacketCaptureDetachRequest
impl Persistable for RollingPacketCaptureDetachRequest
impl StructuralPartialEq for RollingPacketCaptureDetachRequest